package com.hnsensor.api.ys.utils;

import cn.hutool.http.HttpRequest;
import lombok.extern.slf4j.Slf4j;

import java.util.Map;

/**
 * RequestUtil
 *
 * @author Frank
 */
@Slf4j
public class RequestUtil {

    private RequestUtil() {
    }

    /**
     * get请求
     *
     * @param url       请求地址
     * @param paramsMap 请求参数
     * @return 响应结果
     */
    public static String doGet(String url, Map<String, Object> paramsMap) {
        return doRequest(HttpRequest.get(url).form(paramsMap));
    }

    /**
     * post 表单请求
     *
     * @param url       请求地址
     * @param paramsMap 表单参数
     * @return 响应结果
     */
    public static String doPostForm(String url, Map<String, Object> paramsMap) {
        return doRequest(HttpRequest.post(url).form(paramsMap));
    }

    /**
     * post body raw请求
     *
     * @param url  请求地址
     * @param body body参数
     * @return 相应结果
     */
    public static String doPostBody(String url, String body) {
        return doRequest(HttpRequest.post(url).body(body));
    }

    /**
     * 发起请求
     *
     * @param request {@link HttpRequest}
     * @return {@link String}
     */
    public static String doRequest(HttpRequest request) {
        return request.execute().body();
    }

}
